# PFC HP Development

The repository contains in vivo single unit activity (SUA) and local field potential (LFP) data recorded from the prefrontal cortex (PFC) and/or the hippocampal CA1 area (HP) of developing mice (2-12 postnatal days).


## SUA

SUA data is provided as three .csv files, two for the PFC (all units, csv_pfc_full.csv,  and units limited to PFC PL only, csv_pfc_realigned.csv) and one for the HP. 

The first two columns give a unique single unit identifier.
1. the first column corresponds to the animal ID (same as in the meta_data file)
2. the second column corresponds to unit ID

The third column corresponds to the channel on which the unit has been recorded from. There can be multiple units recorded from the same channel. See below for more info.

The columns from the forth onwards (a variable number for every row) correspond to the timestamps of spikes fired by that single unit. The timestamps are given with a sampling rate of 32kHz. 0 corresponds to the beginning of the recording. Recordings are of variable length, but are generally around 1 hour long.

As a quality metrics of the SUA data, we used the number of refractory period violations (RPVs, the  number of action potentials that occurred within less than 2 ms from each other) and correlation 
between the firing rate in the first and second half of the recording:

![](hp_sua_dataset_stats.png)
![](pfc_full_sua_dataset_stats.png)
![](pfc_realigned_sua_dataset_stats.png)

## LFP

LFP data is provided as .npy files. For every animal animal_id_lfp_hp.npy and/or animal_id_lfp_pfc.npy are stored.

Each .npy file contains 2d array, n_channels x n_timepoints. The sampling frequency is 1000Hz. The number of the channel corresponds to the row_number + 1.

## Sharp wave - ripples (SPW-Rs)

The SPW-R data is provided as Pandas dataframe with the following columns:

1. animal_id
2. age
3. with_ripple - True if sharp wave was codetected with ripple and False otherwise
4. amp_rad_layer - SPW amplitude in the hippocampal CA1 radial layers
5. timestamp - the timepoint when SPW occurred. As the timepoint the point of the largest SPW amplitude is taken. The timestamps are given with a sampling rate of 250Hz.

Every row in the dataframe corresponds to one SPW event.


### Electrode geometry

The HP data has been recorded using a laminar probe, with 50 micrometers between channels.

For the HP SUA data, units coming from 7 channels are given:
1. channel 4 corresponds to the "reversal" (the stratum pyramidale) 
2. channels 1:3 correspond to channels that are dorsal (more superficial) to stratum pyramidale
3. channels 5:7 correspond to channels that are ventral (deeper) to stratum pyramidale

The PFC data has been recorded using a 4x4 4-shank probe, with 100 micrometers of spacing between recording sites on the same shank and 125 micrometers between shanks. Here below is a scheme of the electrode and the channel numbering.

![](PFC_electrode_scheme.png)

Channels 1-4 are on the most medial shank, and roughly correspond to layers 2/3.
Channels 13-16 are on the most lateral shank, and roughly correspond to layers 5/6.
Channels 1-5-9-16 are the most dorsal ones, and channels 4-8-12-16 are the most ventral ones.

Relevant for csv_pfc_realigned only:
For some mice, the electrode was slightly misplaced along the medio-lateral axis. This misplacement has already been taken into consideration in the provided channel numbering. For istance, if an electrode was placed 125 micrometers too medial (1 shank too medial), units recorded from the first shank are not included in the dataset, and the other units have been "shifted" by one shank to correct for the misalignment. 
In LFP data, signal traces are also "shifted" to correct for a misplacement. The channels that are out of target area are filled with 0.

## Meta data

The meta_data.xlsx file contains meta data about the mice that are included in the dataset.
The first four columns are self explanatory.
The fifth-sixth-seventh columns refer to the data that is available for the corresponding mice.
The 8th column identifies the experimenter that gathered the data.